@@ -52,7 +52,7 @@ namespace KC {
 
 struct sObjectTableKey {
     sObjectTableKey(unsigned int obj_id, unsigned int order_id) : ulObjId(obj_id), ulOrderId(order_id) {}
-	sObjectTableKey(void) = default;
+	sObjectTableKey() = default;
 	unsigned int ulObjId = 0, ulOrderId = 0;
 
 	bool operator==(const sObjectTableKey &o) const noexcept
