@@ -30,7 +30,7 @@ class ECRestrictionList;
  * Base class for all other ECxxxRestriction classes.
  * It defines the interface needed to hook the various restrictions together.
  */
-class KC_EXPORT ECRestriction {
+class KC_EXPORT Restriction {
 public:
 	enum {
 		Full    = 0,
@@ -38,7 +38,7 @@ public:
 		Shallow = 2		// Creates a new SPropValue, but point to the embedded data from the original structure.
 	};
 
-	KC_HIDDEN virtual ~ECRestriction() = default;
+	KC_HIDDEN virtual ~Restriction() = default;
 
 	/**
 	 * Create an LPSRestiction object that represents the restriction on which CreateMAPIRestriction was called.
@@ -77,21 +77,19 @@ public:
 	 * method is invoked.
 	 * @return	A copy of the current object.
 	 */
-	KC_HIDDEN virtual ECRestriction *Clone() const & = 0;
-	KC_HIDDEN virtual ECRestriction *Clone() && = 0;
-	KC_HIDDEN ECRestrictionList operator+(ECRestriction &&) &&;
-	KC_HIDDEN ECRestrictionList operator+(const ECRestriction &) const;
+	KC_HIDDEN virtual Restriction *Clone() const & = 0;
+	KC_HIDDEN virtual Restriction *Clone() && = 0;
+	KC_HIDDEN ECRestrictionList operator+(Restriction &&) &&;
+	KC_HIDDEN ECRestrictionList operator+(const Restriction &) const;
 
 protected:
-	typedef std::shared_ptr<SPropValue> PropPtr;
-	typedef std::shared_ptr<ECRestriction> ResPtr;
-	typedef std::list<ResPtr>					ResList;
-
-	KC_HIDDEN ECRestriction() = default;
+	KC_HIDDEN Restriction() = default;
 	KC_HIDDEN static HRESULT CopyProp(SPropValue *src, void *base, unsigned int flags, SPropValue **dst);
 	KC_HIDDEN static void DummyFree(void *);
 };
 
+using ECRestriction = Restriction;
+
 /**
  * An ECRestrictionList is a list of ECRestriction objects.
  * This class is used to allow a list of restrictions to be passed in the
@@ -121,10 +119,7 @@ public:
 	}
 
 private:
-	typedef std::shared_ptr<ECRestriction> ResPtr;
-	typedef std::list<ResPtr>					ResList;
-
-	ResList	m_list;
+	std::list<std::shared_ptr<ECRestriction>> m_list;
 
 friend class ECAndRestriction;
 friend class ECOrRestriction;
@@ -152,7 +147,7 @@ class IRestrictionPush : public ECRestriction {
 
 class KC_EXPORT ECAndRestriction KC_FINAL : public IRestrictionPush {
 public:
-	KC_HIDDEN ECAndRestriction() {}
+	KC_HIDDEN ECAndRestriction() = default;
 	ECAndRestriction(const ECRestrictionList &list);
 	KC_HIDDEN ECAndRestriction(ECRestrictionList &&o) :
 		m_lstRestrictions(std::move(o.m_list))
@@ -176,12 +171,12 @@ public:
 	void operator+=(ECRestrictionList &&);
 
 private:
-	ResList	m_lstRestrictions;
+	std::list<std::shared_ptr<ECRestriction>> m_lstRestrictions;
 };
 
 class KC_EXPORT ECOrRestriction KC_FINAL : public IRestrictionPush {
 public:
-	KC_HIDDEN ECOrRestriction() {}
+	KC_HIDDEN ECOrRestriction() = default;
 	ECOrRestriction(const ECRestrictionList &list);
 	KC_HIDDEN ECOrRestriction(ECRestrictionList &&o) :
 		m_lstRestrictions(std::move(o.m_list))
@@ -205,13 +200,13 @@ public:
 	void operator+=(ECRestrictionList &&);
 
 private:
-	ResList	m_lstRestrictions;
+	std::list<std::shared_ptr<ECRestriction>> m_lstRestrictions;
 };
 
 class KC_EXPORT ECNotRestriction KC_FINAL : public IRestrictionPush {
 public:
-	KC_HIDDEN ECNotRestriction(const ECRestriction &restriction)
-	: m_ptrRestriction(ResPtr(restriction.Clone())) 
+	KC_HIDDEN ECNotRestriction(const ECRestriction &restriction) :
+		m_ptrRestriction(restriction.Clone())
 	{ }
 	KC_HIDDEN ECNotRestriction(ECRestriction &&o) :
 		m_ptrRestriction(std::move(o).Clone())
@@ -233,9 +228,9 @@ public:
 	}
 
 private:
-	KC_HIDDEN ECNotRestriction(ResPtr restriction);
+	KC_HIDDEN ECNotRestriction(std::shared_ptr<ECRestriction>);
 
-	ResPtr	m_ptrRestriction;
+	std::shared_ptr<ECRestriction> m_ptrRestriction;
 };
 
 class KC_EXPORT ECContentRestriction KC_FINAL : public ECRestriction {
@@ -246,10 +241,10 @@ public:
 	KC_HIDDEN ECRestriction *Clone() && override { return new ECContentRestriction(std::move(*this)); }
 
 private:
-	KC_HIDDEN ECContentRestriction(unsigned int fuzzy_level, unsigned int tag, PropPtr prop);
+	KC_HIDDEN ECContentRestriction(unsigned int fuzzy_level, unsigned int tag, std::shared_ptr<SPropValue>);
 
 	unsigned int m_ulFuzzyLevel, m_ulPropTag;
-	PropPtr	m_ptrProp;
+	std::shared_ptr<SPropValue> m_ptrProp;
 };
 
 class KC_EXPORT ECBitMaskRestriction KC_FINAL : public ECRestriction {
@@ -276,10 +271,10 @@ public:
 	KC_HIDDEN ECRestriction *Clone() && override { return new ECPropertyRestriction(std::move(*this)); }
 
 private:
-	KC_HIDDEN ECPropertyRestriction(unsigned int relop, unsigned int proptag, PropPtr prop);
+	KC_HIDDEN ECPropertyRestriction(unsigned int relop, unsigned int proptag, std::shared_ptr<SPropValue>);
 
 	unsigned int m_relop, m_ulPropTag;
-	PropPtr	m_ptrProp;
+	std::shared_ptr<SPropValue> m_ptrProp;
 };
 
 class KC_EXPORT ECComparePropsRestriction KC_FINAL : public ECRestriction {
@@ -324,10 +319,9 @@ public:
 	KC_HIDDEN ECRestriction *Clone() && override { return new ECRawRestriction(std::move(*this)); }
 
 private:
-	typedef std::shared_ptr<SRestriction> RawResPtr;
-	KC_HIDDEN ECRawRestriction(RawResPtr restriction);
+	KC_HIDDEN ECRawRestriction(std::shared_ptr<SRestriction>);
 
-	RawResPtr	m_ptrRestriction;
+	std::shared_ptr<SRestriction> m_ptrRestriction;
 };
 
 } /* namespace */
