@@ -11,6 +11,8 @@
 #include <stdexcept>
 #include <iconv.h>
 #include <kopano/charset/traits.h>
+#include <kopano/charset/utf8string.h>
+#include <mapidefs.h>
 
 namespace KC {
 
@@ -86,7 +88,8 @@ class KC_EXPORT iconv_context_base {
 
 	iconv_t	m_cd = reinterpret_cast<iconv_t>(-1);
 	bool m_bForce = true; /* Ignore illegal sequences by default. */
-	bool m_bHTML = false;
+	bool m_bHTML = false, m_translit_run = false;
+	unsigned int m_translit_adv = 1;
 
 	iconv_context_base(const iconv_context_base &) = delete;
 	iconv_context_base &operator=(const iconv_context_base &) = delete;
@@ -168,7 +171,8 @@ class KC_EXPORT_DYCAST iconv_context KC_FINAL :
  *
  * 1. convert_to<dsttype>(dstcharset, srcstring, srcsize, srccharset)
  * 2. convert_to<dsttype>(srcstring, srcsize, srccharset)
- *    autoderived: dstcharset
+ *    autoderived: dstcharset (from dsttype)
+ *    see iconv_charset<dsttype>::name() for the charset that will be assumed
  * 3. convert_to<dsttype>(srcstring)
  *    autoderived: dstcharset, srcsize, srccharset
  *
@@ -217,7 +221,7 @@ inline To_Type convert_to(const char *tocode, const From_Type &from,
  */
 class KC_EXPORT convert_context KC_FINAL {
 public:
-	convert_context(void) = default;
+	convert_context() = default;
 	~convert_context();
 
 	/**
@@ -485,7 +489,7 @@ private:
 	 * @return				A pointer to a iconv_context.
 	 */
 	template<typename To_Type, typename From_Type>
-	KC_HIDDEN iconv_context<To_Type, From_Type> *get_context(void)
+	KC_HIDDEN iconv_context<To_Type, From_Type> *get_context()
 	{
 		context_key key(create_key<To_Type, From_Type>(NULL, NULL));
 		context_map::const_iterator iContext = m_contexts.find(key);
@@ -633,6 +637,27 @@ private:
 
 extern KC_EXPORT HRESULT HrFromException(const convert_exception &);
 
+/*
+ * Even if the definition of TCHAR is different between ASCII and Unicode
+ * builds, some of the oldest functions in the MAPI spec have the Unicodeness
+ * of arguments conveyed by a flags argument, and the char type means nothing.
+ */
+inline utf8string tfstring_to_utf8(const TCHAR *s, unsigned int fl)
+{
+	if (s == nullptr)
+		return utf8string(nullptr);
+	return (fl & MAPI_UNICODE) ? convert_to<utf8string>(reinterpret_cast<const wchar_t *>(s)) :
+	       convert_to<utf8string>(reinterpret_cast<const char *>(s));
+}
+
+inline std::string tfstring_to_lcl(const TCHAR *s, unsigned int fl)
+{
+	if (s == nullptr)
+		return {};
+	return (fl & MAPI_UNICODE) ? convert_to<std::string>(reinterpret_cast<const wchar_t *>(s)) :
+	       convert_to<std::string>(reinterpret_cast<const char *>(s));
+}
+
 #ifdef MAPIDEFS_H
 
 /**
