@@ -89,7 +89,7 @@ extern KC_EXPORT std::string stringify_float(double);
 extern KC_EXPORT std::string stringify_double(double, int prec = 18, bool locale = false);
 extern KC_EXPORT std::wstring wstringify_hex(unsigned int);
 
-#define tstringify			wstringify
+#define tstringify wstringify
 #define tstringify_hex wstringify_hex
 
 static inline unsigned int atoui(const char *s) { return strtoul(s, nullptr, 10); }
@@ -99,10 +99,46 @@ extern KC_EXPORT std::string str_storage(uint64_t bytes, bool unlimited = true);
 extern KC_EXPORT std::string GetServerNameFromPath(const char *);
 extern KC_EXPORT std::string GetServerPortFromPath(const char *);
 
+/**
+ * Parses a string as a boolean by checking for the "negative words" (no, false or 0).
+ * Anything that's not a "negative word" will be considered true.
+ *
+ * @note An empty string is considered true for historic reasons. This is used to maintain existing functionality.
+ */
 static inline bool parseBool(const char *s)
 {
+	/* Empty string was considered true (ZCP), same here (KC) */
 	return s == nullptr || (strcmp(s, "0") != 0 &&
-	       strcmp(s, "false") != 0 && strcmp(s, "no") != 0);
+	       strcasecmp(s, "false") != 0 && strcasecmp(s, "no") != 0);
+}
+
+/**
+ * Parses a string as a boolean by checking for the "negative words" (no, false or 0).
+ * Anything that's not a "negative word" will be considered true.
+ *
+ * @note An empty string is considered false.
+ */
+static inline bool parse_yesno(const char *s)
+{
+	/* Empty string -> false */
+	return s != nullptr && *s != '\0' && parseBool(s);
+}
+
+/**
+ * Parses a string to a boolean by checking for the "positive words" (yes, true, 1).
+ *
+ * This function is useful when a string might contain more than the "yes/no pair".
+ * Since the normal parse function returns true for any string that does not contain one of the possible
+ * "negative words", the addition of this function is useful when knowing if the value is different than the
+ * "yes/no pair" is necessary.
+ * Anything that's not a "positive word" will be considered false.
+ *
+ * @note A null string is considered false.
+ */
+static inline bool parseBoolPositive(const char *s)
+{
+	return s != nullptr && *s != '\0' && (strcmp(s, "1") == 0 || strcasecmp(s, "true") == 0 ||
+		strcmp(s, "yes") == 0);
 }
 
 extern KC_EXPORT std::vector<std::wstring> tokenize(const std::wstring &, const wchar_t sep, bool filter_empty = false);
@@ -184,8 +220,8 @@ Tp join(InputIterator first, InputIterator last, Tp sep)
 }
 
 extern KC_EXPORT std::string format(const char *fmt, ...) KC_LIKE_PRINTF(1, 2);
-extern KC_EXPORT bool kc_starts_with(const std::string &, const std::string &);
-extern KC_EXPORT bool kc_ends_with(const std::string &, const std::string &);
+extern KC_EXPORT bool kc_starts_with(const std::string &, const string_view &);
+extern KC_EXPORT bool kc_ends_with(const std::string &, const string_view &);
 
 template<typename T, typename U> bool kc_istarts_with(T &&a, U &&prefix)
 {
@@ -233,7 +269,7 @@ kc_join(const C &v, const char *sep, F &&func)
 }
 
 extern KC_EXPORT std::string base64_encode(const void *, unsigned int);
-extern KC_EXPORT std::string base64_decode(const std::string &);
+extern KC_EXPORT std::string base64_decode(const string_view &);
 extern KC_EXPORT std::string zcp_md5_final_hex(MD5_CTX *);
 extern KC_EXPORT std::string string_strip_crlf(const char *);
 extern KC_EXPORT bool SymmetricIsCrypted(const char *);
