@@ -10,9 +10,7 @@
  * @addtogroup libfreebusy
  * @{
  */
-#ifndef ECFREEBUSYDATA_H
-#define ECFREEBUSYDATA_H
-
+#pragma once
 #include <kopano/zcdefs.h>
 #include "freebusy.h"
 #include "freebusyguid.h"
@@ -29,12 +27,12 @@ namespace KC {
 class ECFreeBusyData KC_FINAL_OPG : public ECUnknown, public IFreeBusyData {
 public:
 	static HRESULT Create(LONG start, LONG end, const ECFBBlockList &, ECFreeBusyData **);
-	virtual HRESULT QueryInterface(REFIID refiid, void **lppInterface) _kc_override;
+	virtual HRESULT QueryInterface(REFIID refiid, void **lppInterface) KC_OVERRIDE;
 	virtual HRESULT Reload(void *) { return E_NOTIMPL; }
 	virtual HRESULT EnumBlocks(IEnumFBBlock **ppenumfb, const FILETIME &start, const FILETIME &end) override;
-	virtual HRESULT GetDelegateInfo(void *) { return E_NOTIMPL; }
-	virtual HRESULT SetFBRange(LONG rtmStart, LONG rtmEnd);
-	virtual HRESULT GetFBPublishRange(LONG *prtmStart, LONG *prtmEnd);
+	virtual HRESULT GetDelegateInfo(void *) override { return E_NOTIMPL; }
+	virtual HRESULT SetFBRange(int start, int end) override;
+	virtual HRESULT GetFBPublishRange(int *start, int *end) override;
 
 private:
 	ECFreeBusyData(LONG start, LONG end, const ECFBBlockList &);
@@ -46,6 +44,4 @@ private:
 
 } /* namespace */
 
-#endif // ECFREEBUSYDATA_H
-
 /** @} */
