@@ -1,7 +1,8 @@
 #!/usr/local/bin/python3.8
 # SPDX-License-Identifier: AGPL-3.0-or-later
 
-from MAPI.Util import *
+from MAPI.Util import HrGetOneProp, SPropValue
+from MAPI.Tags import PR_FINDER_ENTRYID, PR_ENTRYID
 
 import kopano
 
@@ -16,6 +17,7 @@ work.
 
 FINDROOT_RIGHTS = ['folder_visible', 'read_items', 'create_subfolders', 'edit_own', 'delete_own']
 
+
 def upgrade_findroot(store):
     findroot = store.root.get_folder('FINDER_ROOT')
     if not findroot:
@@ -42,5 +44,6 @@ def main():
         if store.archive_store:
             upgrade_findroot(store.archive_store)
 
+
 if __name__ == '__main__':
     main()
