@@ -23,9 +23,13 @@ from MAPI.Time import (
 import MAPI.Struct
 
 from .compat import (
-    bdec as _bdec, repr as _repr
+    bdec as _bdec
     )
 
+from .errors import (
+        NotFoundError
+)
+
 # TODO to utils.py?
 NANOSECS_BETWEEN_EPOCH = 116444736000000000
 def datetime_to_filetime(d):
@@ -61,7 +65,7 @@ class FreeBusyBlock(object):
         return 'FreeBusyBlock()'
 
     def __repr__(self):
-        return _repr(self)
+        return self.__unicode__()
 
 class FreeBusy(object):
     """FreeBusy class
@@ -92,7 +96,10 @@ class FreeBusy(object):
             ftend = FileTime(0xFFFFFFFFFFFFFFFF)
 
         fb = libfreebusy.IFreeBusySupport()
-        fb.Open(self.store.server.mapisession, self.store.mapiobj, False)
+        try:
+            fb.Open(self.store.server.mapisession, self.store.mapiobj, False)
+        except MAPI.Struct.MAPIErrorNotFound:
+            raise NotFoundError("public store not found")
         fbdata = fb.LoadFreeBusyData([eid], None)
         if fbdata in (0, 1): # TODO what?
             return
@@ -119,7 +126,10 @@ class FreeBusy(object):
         ftend = datetime_to_filetime(end) # TODO tz?
 
         fb = libfreebusy.IFreeBusySupport()
-        fb.Open(self.store.server.mapisession, self.store.mapiobj, False)
+        try:
+            fb.Open(self.store.server.mapisession, self.store.mapiobj, False)
+        except MAPI.Struct.MAPIErrorNotFound:
+            raise NotFoundError("public store not found")
         update, status = fb.LoadFreeBusyUpdate([eid], None)
 
         blocks = []
@@ -141,4 +151,4 @@ class FreeBusy(object):
         return 'FreeBusy()'
 
     def __repr__(self):
-        return _repr(self)
+        return self.__unicode__()
