@@ -2,7 +2,7 @@
 """
 Part of the high-level python bindings for Kopano
 
-Copyright 2018 - Kopano and its licensors (see LICENSE file for details)
+Copyright 2018 - 2019 Kopano and its licensors (see LICENSE file)
 """
 
 PidLidEmail1AddressType = 'PT_UNICODE:PSETID_Address:0x8082'
@@ -79,3 +79,5 @@ PidLidWorkAddressCity = 'PT_UNICODE:PSETID_Address:0x8046'
 PidLidWorkAddressState = 'PT_UNICODE:PSETID_Address:0x8047'
 PidLidWorkAddressPostalCode = 'PT_UNICODE:PSETID_Address:0x8048'
 PidLidWorkAddressCountry = 'PT_UNICODE:PSETID_Address:0x8049'
+PidLidDistributionListMembers = 'PT_MV_BINARY:PSETID_Address:0x8055'
+PidLidDistributionListOneOffMembers = 'PT_MV_BINARY:PSETID_Address:0x8054'
