@@ -32,8 +32,12 @@ from MAPI.Tags import (
     PR_DISPLAY_NAME_W, PR_SENT_REPRESENTING_NAME_W, PR_SMTP_ADDRESS_W,
     PR_MESSAGE_ATTACHMENTS, PR_ATTACH_LONG_FILENAME_W, PR_MESSAGE_RECIPIENTS,
     PR_RECIPIENT_TYPE, PR_SENDER_EMAIL_ADDRESS_W, PR_EMAIL_ADDRESS_W,
+    PR_GIVEN_NAME_W, PR_COMPANY_NAME_W, PR_SURNAME_W, PR_OFFICE_LOCATION_W,
+    PR_MOBILE_TELEPHONE_NUMBER_W, PR_BUSINESS_TELEPHONE_NUMBER_W,
+    PR_POSTAL_CODE_W, PR_BIRTHDAY, PR_PREFERRED_BY_NAME_W,
+    PR_RESPONSIBILITY, PR_USER_NAME, PR_FOLDER_CHILD_COUNT,
+    PR_CONTENT_COUNT, PR_PARENT_ENTRYID, PR_CONTENT_UNREAD
 )
-
 from MAPI.Struct import (
     SOrRestriction, SAndRestriction, SNotRestriction, SContentRestriction,
     SPropValue, SPropertyRestriction, SBitMaskRestriction, SSubRestriction,
@@ -73,8 +77,8 @@ MESSAGE_KEYWORD_PROP = {
     'body': PR_BODY_W,
     'content': PR_BODY_W, # TODO what does content mean
     'received': PR_MESSAGE_DELIVERY_TIME,
-    'hasattachment': PR_HASATTACH,
-    'hasattachments': PR_HASATTACH,
+    'hasAttachment': PR_HASATTACH,
+    'hasAttachments': PR_HASATTACH,
     'size': PR_MESSAGE_SIZE,
     'read': (PR_MESSAGE_FLAGS, MSGFLAG_READ),
     'from': PR_SENT_REPRESENTING_NAME_W, # TODO email address
@@ -95,19 +99,40 @@ CONTACT_KEYWORD_PROP = {
 
 USER_KEYWORD_PROP = {
     'name': PR_DISPLAY_NAME_W,
-    'email': PR_SMTP_ADDRESS_W,
+    'givenName': PR_GIVEN_NAME_W,
+    'preferredName': PR_PREFERRED_BY_NAME_W,
+    'surname': PR_SURNAME_W,
+    'userPrincipalName': PR_USER_NAME,
+    'mail': PR_SMTP_ADDRESS_W,
+    'mobilePhone': PR_MOBILE_TELEPHONE_NUMBER_W,
+    'postalCode': PR_POSTAL_CODE_W,
+    'birthday': PR_BIRTHDAY,
+    'companyName': PR_COMPANY_NAME_W,
+    'officeLocation': PR_OFFICE_LOCATION_W,
+    'businessPhones': PR_BUSINESS_TELEPHONE_NUMBER_W,
+    'responsibilities': PR_RESPONSIBILITY,
+}
+
+FOLDER_KEYWORD_PROP = {
+    'displayName': PR_DISPLAY_NAME_W,
+    'childFolderCount': PR_FOLDER_CHILD_COUNT,
+    'parentFolderId': PR_PARENT_ENTRYID,
+    'totalItemCount': PR_CONTENT_COUNT,
+    'unreadItemCount': PR_CONTENT_UNREAD,
 }
 
 TYPE_KEYWORD_PROPMAP = {
     'message': MESSAGE_KEYWORD_PROP,
     'contact': CONTACT_KEYWORD_PROP,
     'user': USER_KEYWORD_PROP,
+    'folder': FOLDER_KEYWORD_PROP,
 }
 
 DEFAULT_PROPTAGS = {
     'message': [PR_SUBJECT_W, PR_BODY_W, PR_SENT_REPRESENTING_NAME_W],
     'contact': [PR_DISPLAY_NAME_W, EMAIL1_NAME],
     'user': [PR_DISPLAY_NAME_W, PR_SMTP_ADDRESS_W],
+    'folder': [PR_DISPLAY_NAME_W],
 }
 
 OP_RELOP = {
