@@ -41,10 +41,9 @@ from MAPI.Time import (
 from dateutil.rrule import (
     DAILY, WEEKLY, MONTHLY, MO, TU, TH, FR, WE, SA, SU, rrule, rruleset
 )
-import dateutil.tz
 
 from .compat import (
-    repr as _repr, benc as _benc, bdec as _bdec, fake_unicode as _unicode
+    benc as _benc, bdec as _bdec
 )
 from .errors import (
     ArgumentError,
@@ -52,10 +51,9 @@ from .errors import (
 from .defs import (
     ARO_SUBJECT, ARO_MEETINGTYPE, ARO_REMINDERDELTA, ARO_REMINDERSET,
     ARO_LOCATION, ARO_BUSYSTATUS, ARO_ATTACHMENT, ARO_SUBTYPE,
-    ARO_APPTCOLOR, ASF_CANCELED, FB_STATUS, STATUS_FB
+    ARO_APPTCOLOR, ASF_CANCELED, FB_STATUS, STATUS_FB,
 )
 
-LOCAL = dateutil.tz.tzlocal()
 
 from .attendee import Attendee
 
@@ -216,7 +214,7 @@ class Recurrence(object):
              (PATTERN_WEEKLY, PATTERN_MONTHNTH, PATTERN_HJMONTHNTH)):
             pts = 0
             for weekday in value:
-                pts |= (1 << WEEKDAYS_REV[weekday])
+                pts |= (1 << WEEKDAYS_REV[weekday.lower()])
             self._pattern_type_specific[0] = pts
 
         self._weekdays = value
@@ -278,7 +276,7 @@ class Recurrence(object):
                 'third': 3,
                 'fourth': 4,
                 'last': 5,
-            }[_unicode(value)]
+            }[str(value)]
         except KeyError:
             raise ArgumentError('invalid recurrence index: %s' % value)
 
@@ -367,17 +365,25 @@ class Recurrence(object):
         self.item[PidLidClipEnd] = self.end
 
     # TODO fit-to-period
-    def occurrences(self, start=None, end=None):
+    def occurrences(self, start=None, end=None, page_start=None,
+                    page_limit=None, order=None):
         """Return all recurrence :class:`occurrences <Occurrence>`,
         optionally overlapping with a given time window.
 
         :param start: start of time window (optional)
         :param end: end of time window (optional)
         """
-        recurrences = self.recurrences
+        count = 0
+        pos = 0
+        try:
+            recurrences = self.recurrences
+        except Exception:
+            self.item.server.log.exception('failed to expand recurrence, skipped %r', self.item.entryid)
+            return
+
         if start and end:
-            start = _timezone._tz2(start, LOCAL, self._tzinfo)
-            end = _timezone._tz2(end, LOCAL, self._tzinfo)
+            start = _timezone._tz2(start, _timezone.LOCAL, self._tzinfo)
+            end = _timezone._tz2(end, _timezone.LOCAL, self._tzinfo)
             recurrences = recurrences.between(start, end)
 
         start_exc_ext = {}
@@ -389,6 +395,7 @@ class Recurrence(object):
                 _utils.unixtime_to_rectime(calendar.timegm(d.timetuple()))
 
             subject = self.item.subject
+            # TODO: lazy load location move logic to Occurrence class
             location = self.item.location
             busystatus = self.item.busystatus
             exception = False
@@ -411,12 +418,17 @@ class Recurrence(object):
                 d = _timezone._tz2(d, self.item.tzinfo, _timezone.LOCAL)
             e = d + datetime.timedelta(minutes=minutes)
 
-            occ = Occurrence(self.item, d, e, subject, location,
+            occurrence = Occurrence(self.item, d, e, subject, location,
                 busystatus=busystatus, basedate_val=basedate_val,
                 exception=exception)
 
-            if (not start or occ.end > start) and (not end or occ.start < end):
-                yield occ
+            if (not start or start < occurrence.end) and (not end or end > occurrence.start):
+                if page_start is None or pos >= page_start:
+                    yield occurrence
+                    count += 1
+                if page_limit is not None and count >= page_limit:
+                    break
+                pos += 1
 
     def occurrence(self, entryid):
         entryid = _bdec(entryid)
@@ -496,13 +508,13 @@ class Recurrence(object):
         if start:
             if tzinfo:
                 # Convert to item timezone to ensure the offset is correct.
-                start = _timezone._tz2(start, LOCAL, tzinfo)
+                start = _timezone._tz2(start, _timezone.LOCAL, tzinfo)
             self._starttime_offset = start.hour * 60 + start.minute
         end = item.end
         if end:
             if tzinfo:
                 # Convert to item timezone to ensure the offset is correct.
-                end = _timezone._tz2(end, LOCAL, tzinfo)
+                end = _timezone._tz2(end, _timezone.LOCAL, tzinfo)
             self._endtime_offset = end.hour * 60 + end.minute
         if save:
             self._save()
@@ -512,9 +524,14 @@ class Recurrence(object):
         self._monthday = None
         self._weekdays = None
         self._month = None
+        self._exceptions = []
+        self._extended_exceptions = []
 
         # AppointmentRecurrencePattern
-        value = self.item.prop(PidLidAppointmentRecur).value
+        value = self.item._get_fast(self.item.store._pidlid_proptag(PidLidAppointmentRecur))
+        # TODO: throw NotFound exception instead if value is None?
+        if not value:
+            value = self.item.prop(PidLidAppointmentRecur).value
 
         # RecurrencePattern
         self._reader_version = _utils.unpack_short(value, 0)
@@ -581,7 +598,6 @@ class Recurrence(object):
         pos += SHORT
 
         # ExceptionInfo
-        self._exceptions = []
         # using modcount, as PHP seems to not update exception_count?
         # equal according to docs
         for i in range(0, self._modified_instance_count):
@@ -659,7 +675,6 @@ class Recurrence(object):
         pos += _utils.unpack_long(value, pos) + LONG
 
         # ExtendedException
-        self._extended_exceptions = []
         for exception in self._exceptions:
             extended_exception = {}
 
@@ -845,11 +860,15 @@ class Recurrence(object):
             end = None
         else:
             end = self.end + datetime.timedelta(minutes=self._endtime_offset)
-            # FIXME: add one day, so that we don't miss the last recurrence,
-            # since the end date is for example 11-3-2015 on 1:00
-            # But the recurrence is on 8:00 that day and we should include it.
+            # NOTE(longsleep): Move time to end of the last day so that we don't
+            # miss the last recurrence, since the end date is for example
+            # 11-3-2015 on 1:00 but the recurrence is on 8:00 that day and we
+            # should include it.
+            # TODO(longsleep): Figure out why this is not done for start as well.
+            # TODO(longsleep): Figure out why this is not done for monthly.
+            # TODO(longsleep): Maybe this can be removed? Add test case.
             if self._pattern_type == PATTERN_WEEKLY:
-                end += datetime.timedelta(days=1)
+                end = end.replace(hour=23, minute=59, second=59, microsecond=999999)
 
         # TODO for occurrence count?
 
@@ -997,6 +1016,12 @@ class Recurrence(object):
             exception['appointment_color'] = appointment_color
 
         if extended:
+            # set start/end date when location or subject is overridden as per MS-OXOCAL 2.2.1.44.2
+            if exception['override_flags'] & ARO_SUBJECT or exception['override_flags'] & ARO_LOCATION:
+                # Retrieve the start date
+                extended_exception['start_datetime'] = exception['start_datetime']
+                extended_exception['end_datetime'] = exception['end_datetime']
+
             if startdate:
                 extended_exception['start_datetime'] = startdate_val
             if enddate:
@@ -1013,7 +1038,7 @@ class Recurrence(object):
         if (cal_item.get(PidLidReminderSet) and \
             cal_item.get(PidLidReminderDelta)):
             next_date = self.recurrences.after(
-                datetime.datetime.now(self._tzinfo).replace(tzinfo=None))
+                datetime.datetime.now(_timezone.UTC).astimezone(self._tzinfo).replace(tzinfo=None))
             if next_date:
                 next_date = _timezone._to_utc(next_date, self._tzinfo)
                 dueby = next_date - datetime.timedelta(
@@ -1137,7 +1162,7 @@ class Recurrence(object):
             table = item.mapiobj.OpenProperty(PR_MESSAGE_RECIPIENTS,
                 IID_IMAPITable, MAPI_UNICODE, 0)
             table.SetColumns(_meetingrequest.RECIP_PROPS, 0)
-            recips = list(table.QueryRows(-1, 0))
+            recips = list(table.QueryRows(2147483647, 0))
 
             for recip in recips:
                 flags = PpropFindProp(recip, PR_RECIPIENT_FLAGS)
@@ -1223,7 +1248,7 @@ class Recurrence(object):
                 IID_IMAPITable, MAPI_UNICODE, 0)
             table.SetColumns(_meetingrequest.RECIP_PROPS, 0)
 
-            recips = list(table.QueryRows(-1, 0))
+            recips = list(table.QueryRows(2147483647, 0))
             for recip in recips:
                 flags = PpropFindProp(recip, PR_RECIPIENT_FLAGS)
                 if flags and flags.Value != (recipOrganizer | recipSendable):
@@ -1304,7 +1329,7 @@ class Recurrence(object):
         return 'Recurrence()'
 
     def __repr__(self):
-        return _repr(self)
+        return self.__unicode__()
 
 
 class Occurrence(object):
@@ -1352,7 +1377,7 @@ class Occurrence(object):
 
     @location.setter
     def location(self, value):
-        value = _unicode(value)
+        value = str(value)
         self._update(location=value)
         self._location = value
 
@@ -1362,7 +1387,7 @@ class Occurrence(object):
 
     @subject.setter
     def subject(self, value):
-        value = _unicode(value)
+        value = str(value)
         self._update(subject=value)
         self._subject = value
 
@@ -1494,6 +1519,40 @@ class Occurrence(object):
         else:
             self.item.send(copy_to_sentmail)
 
+    @property
+    def text(self):
+        return self.item.text
+
+    @text.setter
+    def text(self, value):
+        setattr(self.item, 'text', value)
+
+    @property
+    def onlinemeetingurl(self):
+        return self.item.onlinemeetingurl
+
+    @onlinemeetingurl.setter
+    def onlinemeetingurl(self, value):
+        setattr(self.item, 'onlinemeetingurl', value)
+
+    @property
+    def reminder(self):
+        """Is appointment reminder set."""
+        return self.item.reminder
+
+    @reminder.setter
+    def reminder(self, value):
+        self.item.reminder = value
+
+    @property
+    def reminder_minutes(self):
+        """Reminder minutes before appointment."""
+        return self.item.reminder_minutes
+
+    @reminder_minutes.setter
+    def reminder_minutes(self, value):
+        self.item.reminder_minutes = value
+
     # TODO get from exception message by default? eg subject, attendees..
     def __getattr__(self, x):
         return getattr(self.item, x)
@@ -1502,4 +1561,4 @@ class Occurrence(object):
         return 'Occurrence(%s)' % self.subject
 
     def __repr__(self):
-        return _repr(self)
+        return self.__unicode__()
