@@ -2,14 +2,17 @@
 """
 Part of the high-level python bindings for Kopano
 
-Copyright 2005 - 2016 Zarafa and its licensors (see LICENSE file for details)
-Copyright 2016 - Kopano and its licensors (see LICENSE file for details)
+Copyright 2005 - 2016 Zarafa and its licensors (see LICENSE file)
+Copyright 2016 - 2019 Kopano and its licensors (see LICENSE file)
 """
 
 import binascii
 import os
+try:
+    import cPickle as pickle
+except ImportError:
+    import _pickle as pickle
 import struct
-import sys
 import time
 
 from MAPI import (
@@ -39,16 +42,16 @@ MAX_SAVE_RETRIES = int(os.getenv('PYKO_MAPI_SAVE_MAX_RETRIES', 3))
 from .compat import bdec as _bdec
 from .errors import Error, NotFoundError, ArgumentError
 
-if sys.hexversion >= 0x03000000:
-    from . import table as _table
-    from . import permission as _permission
-    from . import user as _user
-    from . import group as _group
-else: # pragma: no cover
-    import table as _table
-    import permission as _permission
-    import user as _user
-    import group as _group
+from . import table as _table
+from . import permission as _permission
+from . import user as _user
+from . import group as _group
+
+def pickle_loads(s):
+    return pickle.loads(s, encoding='bytes')
+
+def pickle_dumps(s):
+    return pickle.dumps(s, protocol=2)
 
 def stream(mapiobj, proptag):
     stream = mapiobj.OpenProperty(proptag, IID_IStream, 0, 0)
@@ -73,13 +76,15 @@ def stream(mapiobj, proptag):
 
     return data
 
-def _openentry_helper(mapistore, entryid, flags): # avoid underwater action for archived items
+# avoid underwater action for archived items
+def _openentry_helper(mapistore, entryid, flags):
     try:
         return mapistore.OpenEntry(entryid, IID_IECMessageRaw, flags)
     except MAPIErrorInterfaceNotSupported:
         return mapistore.OpenEntry(entryid, None, flags)
 
-def openentry_raw(mapistore, entryid, flags): # try to open read/write, falling back to read-only
+# try to open read/write, falling back to read-only
+def openentry_raw(mapistore, entryid, flags):
     try:
         return _openentry_helper(mapistore, entryid, flags | MAPI_MODIFY)
     except MAPIErrorNoAccess:
@@ -105,7 +110,8 @@ def unixtime_to_rectime(t):
 
 def permissions(obj):
         try:
-            acl_table = obj.mapiobj.OpenProperty(PR_ACL_TABLE, IID_IExchangeModifyTable, 0, 0)
+            acl_table = obj.mapiobj.OpenProperty(
+                PR_ACL_TABLE, IID_IExchangeModifyTable, 0, 0)
         except MAPIErrorNotFound:
             return
         table = _table.Table(
@@ -122,14 +128,21 @@ def permission(obj, member, create):
             if permission.member == member:
                 return permission
         if create:
-            acl_table = obj.mapiobj.OpenProperty(PR_ACL_TABLE, IID_IExchangeModifyTable, 0, 0)
-            if isinstance(member, _user.User): # XXX *.id_ or something..?
+            acl_table = obj.mapiobj.OpenProperty(
+                PR_ACL_TABLE, IID_IExchangeModifyTable, 0, 0)
+
+            if isinstance(member, _user.User): # TODO *.id_ or something..?
                 memberid = member.userid
             elif isinstance(member, _group.Group):
                 memberid = member.groupid
             else:
                 memberid = member.companyid
-            acl_table.ModifyTable(0, [ROWENTRY(ROW_ADD, [SPropValue(PR_MEMBER_ENTRYID, _bdec(memberid)), SPropValue(PR_MEMBER_RIGHTS, 0)])])
+
+            props = [
+                SPropValue(PR_MEMBER_ENTRYID, _bdec(memberid)),
+                SPropValue(PR_MEMBER_RIGHTS, 0)
+            ]
+            acl_table.ModifyTable(0, [ROWENTRY(ROW_ADD, props)])
             return obj.permission(member)
         else:
             raise NotFoundError("no permission entry for '%s'" % member.name)
@@ -161,9 +174,11 @@ def human_to_bytes(s):
     except ValueError:
         raise ArgumentError('invalid size: %r' % init)
     letter = s.strip()
-    for sset in [('b', 'k', 'm', 'g', 't', 'p', 'e', 'z', 'y'),
-                 ('b', 'kb', 'mb', 'gb', 'tb', 'pb', 'eb', 'zb', 'yb'),
-                 ('b', 'kib', 'mib', 'gib', 'tib', 'pib', 'eib', 'zib', 'yib')]:
+    for sset in [
+        ('b', 'k', 'm', 'g', 't', 'p', 'e', 'z', 'y'),
+        ('b', 'kb', 'mb', 'gb', 'tb', 'pb', 'eb', 'zb', 'yb'),
+        ('b', 'kib', 'mib', 'gib', 'tib', 'pib', 'eib', 'zib', 'yib')
+    ]:
         if letter in sset:
             break
     else:
@@ -190,7 +205,7 @@ def _bdec_eid(entryid):
     try:
         return _bdec(entryid)
     except (TypeError, AttributeError, binascii.Error):
-        raise ArgumentError("invalid entryid: %r" % entryid)
+        raise ArgumentError("invalid entryid: %r" % entryid) from None
 
 def _save(mapiobj):
     # retry on deadlock or other temporary issue
