@@ -682,8 +682,11 @@ class Service(kopano.Service):
         # specified stores
         if self.options.stores:
             for store in self.server.stores():
-                if store.public:
-                    target = 'public' + ('@'+store.company.name if store.company.name != 'Default' else '')
+                if store.public and store.company:
+                    if store.company.name != 'Default':
+                        target = 'public@' + store.company.name
+                    else:
+                        target = 'public'
                 else:
                     target = store.guid
                 jobs.append((store, None, os.path.join(output_dir, target)))
@@ -722,7 +725,7 @@ class Service(kopano.Service):
         # now dive into 'items', and restore desired items
         with closing(dbopen(data_path+'/items')) as db_items:
           with closing(dbopen(data_path+'/index')) as db_index:
-            index = dict((a, pickle_loads(b)) for (a,b) in db_index.iteritems())
+            index = dict((a, pickle_loads(b)) for (a,b) in db_index.items())
 
             # determine sourcekey(s) to restore
             sourcekeys = db_index.keys()
@@ -879,7 +882,7 @@ def show_contents(data_path, options):
         # filter items on date using 'index' database
         if os.path.exists(data_path+'/index'):
             with closing(bsddb.hashopen(data_path+'/index')) as db:
-                for key, value in db.iteritems():
+                for key, value in db.items():
                     d = pickle_loads(value)
                     if ((key == b'folder') or
                         (options.period_begin and d[b'last_modified'] < options.period_begin) or
