@@ -1,11 +1,9 @@
 #!/usr/local/bin/python3.8
 # SPDX-License-Identifier: AGPL-3.0-only
-from __future__ import print_function
 from .version import __version__
 
 import collections
 from contextlib import closing
-import codecs
 import fcntl
 import os.path
 
