@@ -1,5 +1,8 @@
 #!@PYTHON@
 # SPDX-License-Identifier: AGPL-3.0-or-later
+
+from __future__ import print_function
+
 import collections
 from datetime import datetime, timedelta
 import os
@@ -120,7 +123,10 @@ def main():
             mr.process_cancellation(delete=True)
 
     now = datetime.now()
-    user.freebusy.publish(now - timedelta(7), now + timedelta(180))
+    try:
+        user.freebusy.publish(now - timedelta(7), now + timedelta(180))
+    except kopano.errors.NotFoundError as e:
+        print("Unable to publish freebusy information: " + str(e), file=sys.stderr)
 
 if __name__ == '__main__':
     main() # pragma: no cover
